aurora.test\_utils.synthetic package
====================================

Submodules
----------

aurora.test\_utils.synthetic.make\_processing\_configs module
-------------------------------------------------------------

.. automodule:: aurora.test_utils.synthetic.make_processing_configs
   :members:
   :undoc-members:
   :show-inheritance:

aurora.test\_utils.synthetic.paths module
-----------------------------------------

.. automodule:: aurora.test_utils.synthetic.paths
   :members:
   :undoc-members:
   :show-inheritance:

aurora.test\_utils.synthetic.processing\_helpers module
-------------------------------------------------------

.. automodule:: aurora.test_utils.synthetic.processing_helpers
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: aurora.test_utils.synthetic
   :members:
   :undoc-members:
   :show-inheritance:
